aboutsummaryrefslogtreecommitdiff
path: root/drivers/media/video/pvrusb2/pvrusb2-hdw.c
diff options
context:
space:
mode:
authorGary Francis <gary.francis@serverlan.plus.com>2009-11-25 03:03:31 -0300
committerMauro Carvalho Chehab <mchehab@redhat.com>2009-12-05 18:42:11 -0200
commit75727460a6dfa4c7fd8472a99269982ec4662e64 (patch)
tree90cdd7d5edc0a13dcc15b7bfdcde24a5dd4181b3 /drivers/media/video/pvrusb2/pvrusb2-hdw.c
parent9081d9018581e01eec9085a80c86bc07e7168f18 (diff)
V4L/DVB (13500): pvrusb2: Fix lingering 16KB FX2 Firmware issues
These are additional fixes to enable proper pvrusb2 support of 16KB sized FX2 firmware. Signed-off-by: Mike Isely <isely@pobox.com> Signed-off-by: Mauro Carvalho Chehab <mchehab@redhat.com>
Diffstat (limited to 'drivers/media/video/pvrusb2/pvrusb2-hdw.c')
-rw-r--r--drivers/media/video/pvrusb2/pvrusb2-hdw.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/drivers/media/video/pvrusb2/pvrusb2-hdw.c b/drivers/media/video/pvrusb2/pvrusb2-hdw.c
index e93f3e2c25e..1bbdab08fe0 100644
--- a/drivers/media/video/pvrusb2/pvrusb2-hdw.c
+++ b/drivers/media/video/pvrusb2/pvrusb2-hdw.c
@@ -1522,8 +1522,8 @@ static int pvr2_upload_firmware1(struct pvr2_hdw *hdw)
trace_firmware("Upload done (%d bytes sent)",ret);
- /* We should have written 8192 bytes */
- if (ret == 8192) {
+ /* We should have written fwsize bytes */
+ if (ret == fwsize) {
hdw->fw1_state = FW1_STATE_RELOAD;
return 0;
}